You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by bi...@apache.org on 2015/05/22 22:11:48 UTC

ambari git commit: AMBARI-11286 Fix quicklinks for Accumulo Monitor UI when SSL is enabled (billie)

Repository: ambari
Updated Branches:
  refs/heads/trunk cd6398a1d -> b23582532


AMBARI-11286 Fix quicklinks for Accumulo Monitor UI when SSL is enabled (billie)


Project: http://git-wip-us.apache.org/repos/asf/ambari/repo
Commit: http://git-wip-us.apache.org/repos/asf/ambari/commit/b2358253
Tree: http://git-wip-us.apache.org/repos/asf/ambari/tree/b2358253
Diff: http://git-wip-us.apache.org/repos/asf/ambari/diff/b2358253

Branch: refs/heads/trunk
Commit: b235825327c2f23915677b1f0d7707c56f5cddad
Parents: cd6398a
Author: Billie Rinaldi <bi...@gmail.com>
Authored: Fri May 22 13:05:41 2015 -0700
Committer: Billie Rinaldi <bi...@gmail.com>
Committed: Fri May 22 13:05:51 2015 -0700

----------------------------------------------------------------------
 ambari-web/app/models/quick_links.js                |  4 +++-
 ambari-web/app/views/common/quick_view_link_view.js | 16 ++++++++++++++--
 2 files changed, 17 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ambari/blob/b2358253/ambari-web/app/models/quick_links.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/models/quick_links.js b/ambari-web/app/models/quick_links.js
index 564036d..10bc923 100644
--- a/ambari-web/app/models/quick_links.js
+++ b/ambari-web/app/models/quick_links.js
@@ -319,8 +319,10 @@ App.QuickLinks.FIXTURES = [
     service_id: 'ACCUMULO',
     template:'%@://%@:%@/',
     http_config: 'monitor.port.client',
+    https_config: 'monitor.port.client',
     site: 'accumulo-site',
     regex: '^(\\d+)$',
-    default_http_port: 50095
+    default_http_port: 50095,
+    default_https_port: 50095
   }
 ];

http://git-wip-us.apache.org/repos/asf/ambari/blob/b2358253/ambari-web/app/views/common/quick_view_link_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/quick_view_link_view.js b/ambari-web/app/views/common/quick_view_link_view.js
index 749a520..09176ae 100644
--- a/ambari-web/app/views/common/quick_view_link_view.js
+++ b/ambari-web/app/views/common/quick_view_link_view.js
@@ -75,7 +75,7 @@ App.QuickViewLinks = Em.View.extend({
   /**
    * list of files that contains properties for enabling/disabling ssl
    */
-  requiredSiteNames: ['hadoop-env','yarn-env','hbase-env','oozie-env','mapred-env','storm-env', 'falcon-env', 'core-site', 'hdfs-site', 'hbase-site', 'oozie-site', 'yarn-site', 'mapred-site', 'storm-site', 'spark-defaults'],
+  requiredSiteNames: ['hadoop-env','yarn-env','hbase-env','oozie-env','mapred-env','storm-env', 'falcon-env', 'core-site', 'hdfs-site', 'hbase-site', 'oozie-site', 'yarn-site', 'mapred-site', 'storm-site', 'spark-defaults', 'accumulo-site'],
   /**
    * Get public host name by its host name.
    *
@@ -283,7 +283,7 @@ App.QuickViewLinks = Em.View.extend({
 
   /**
    * services that supports security. this array is used to find out protocol.
    * becides GANGLIA, YARN, MAPREDUCE2. These properties use
    * their properties to know protocol
    */
   servicesSupportsHttps: ["HDFS", "HBASE"],
@@ -329,6 +329,17 @@ App.QuickViewLinks = Em.View.extend({
         }
         return hadoopSslEnabled ? "https" : "http";
         break;
+      case "ACCUMULO":
+        var accumuloProperties = configProperties && configProperties.findProperty('type', 'accumulo-site');
+        if (accumuloProperties && accumuloProperties.properties) {
+          if (accumuloProperties.properties['monitor.ssl.keyStore'] && accumuloProperties.properties['monitor.ssl.trustStore']) {
+            return "https";
+          } else {
+            return "http";
+          }
+        }
+        return "http";
+        break;
       default:
         return this.get('servicesSupportsHttps').contains(service_id) && hadoopSslEnabled ? "https" : "http";
     }
@@ -374,6 +385,7 @@ App.QuickViewLinks = Em.View.extend({
       case "storm":
       case "spark":
       case "falcon":
+      case "accumulo":
         return "_blank";
         break;
       default:
@@ -283,7 +283,7 @@ App.QuickViewLinks = Em.View.extend({
   /**
    * services that supports security. this array is used to find out protocol.
-   * becides GANGLIA, YARN, MAPREDUCE2. These properties use
+   * becides GANGLIA, YARN, MAPREDUCE2, ACCUMULO. These services use
    * their properties to know protocol
    */